@@ -15,8 +15,9 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_module.c,v 1.52.2.2 2004/10/18 17:43:51 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_module.c,v 1.52.2.4 2004/12/07 06:12:13 shadow Exp $");
 
+#include <linux/module.h> /* early to avoid printf->printk mapping */
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
 #include "h/unistd.h"		/* For syscall numbers. */
@@ -26,7 +27,6 @@ RCSID
 #include "../asm/ia32_unistd.h"
 #endif
 
-#include <linux/module.h>
 #include <linux/proc_fs.h>
 #include <linux/slab.h>
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
@@ -68,7 +68,9 @@ static void **sys_call_table;	/* safer for other linuces */
 
 extern struct file_system_type afs_fs_type;
 
+#if !defined(AFS_LINUX24_ENV)
 static long get_page_offset(void);
+#endif
 
 #if defined(AFS_LINUX24_ENV)
 DECLARE_MUTEX(afs_global_lock);
@@ -138,12 +140,52 @@ static struct file_operations afs_syscall_fops = {
     .ioctl = afs_ioctl,
 };
 
+int
+csdbproc_read(char *buffer, char **start, off_t offset, int count,
+	      int *eof, void *data)
+{
+    int len, j;
+    struct afs_q *cq, *tq;
+    struct cell *tc;
+    char tbuffer[16];
+    afs_uint32 addr;
+    
+    len = 0;
+    ObtainReadLock(&afs_xcell);
+    for (cq = CellLRU.next; cq != &CellLRU; cq = tq) {
+	tc = QTOC(cq); tq = QNext(cq);
+	len += sprintf(buffer + len, ">%s #(%d/%d)\n", tc->cellName, 
+		       tc->cellNum, tc->cellIndex);
+	for (j = 0; j < MAXCELLHOSTS; j++) {
+	    if (!tc->cellHosts[j]) break;
+	    addr = ntohl(tc->cellHosts[j]->addr->sa_ip);
+	    sprintf(tbuffer, "%d.%d.%d.%d", 
+		    (int)((addr>>24) & 0xff), (int)((addr>>16) & 0xff),
+		    (int)((addr>>8)  & 0xff), (int)( addr      & 0xff));
+            len += sprintf(buffer + len, "%s #%s\n", tbuffer, tbuffer);
+	}
+    }
+    ReleaseReadLock(&afs_xcell);
+    
+    if (offset >= len) {
+	*start = buffer;
+	*eof = 1;
+	return 0;
+    }
+    *start = buffer + offset;
+    if ((len -= offset) > count)
+	return count;
+    *eof = 1;
+    return len;
+}
+
 static struct proc_dir_entry *openafs_procfs;
 
 static int
 afsproc_init()
 {
     struct proc_dir_entry *entry1;
+    struct proc_dir_entry *entry2;
 
     openafs_procfs = proc_mkdir(PROC_FSDIRNAME, proc_root_fs);
     entry1 = create_proc_entry(PROC_SYSCALL_NAME, 0666, openafs_procfs);
@@ -152,12 +194,15 @@ afsproc_init()
 
     entry1->owner = THIS_MODULE;
 
+    entry2 = create_proc_read_entry(PROC_CELLSERVDB_NAME, (S_IFREG|S_IRUGO), openafs_procfs, csdbproc_read, NULL);
+
     return 0;
 }
 
 static void
 afsproc_exit()
 {
+    remove_proc_entry(PROC_CELLSERVDB_NAME, openafs_procfs);
     remove_proc_entry(PROC_SYSCALL_NAME, openafs_procfs);
     remove_proc_entry(PROC_FSDIRNAME, proc_root_fs);
 }
@@ -254,8 +299,11 @@ init_module(void)
     unsigned long *ptr;
     unsigned long offset=0;
     unsigned long datalen=0;
-    int ret;
+#if defined(EXPORTED_KALLSYMS_SYMBOL)
     unsigned long token=0;
+#endif
+#if defined(EXPORTED_KALLSYMS_SYMBOL) || defined(EXPORTED_KALLSYMS_ADDRESS)
+    int ret;
     char *mod_name;
     unsigned long mod_start=0;
     unsigned long mod_end=0;
@@ -265,6 +313,7 @@ init_module(void)
     char *sym_name;
     unsigned long sym_start=0;
     unsigned long sym_end=0;
+#endif
 #endif /* EXPORTED_SYS_CALL_TABLE */
 
     RWLOCK_INIT(&afs_xosi, "afs_xosi");
@@ -366,7 +415,7 @@ init_module(void)
     if (!sys_call_table) {
 	printf("Failed to find address of sys_call_table\n");
     } else {
-	printf("Found sys_call_table at %x\n", sys_call_table);
+	printf("Found sys_call_table at %lx\n", (unsigned long)sys_call_table);
 #if defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_S390X_LINUX24_ENV)
 	error cant support this yet.;
 #endif /* AFS_SPARC64_LINUX20_ENV */
@@ -428,10 +477,10 @@ init_module(void)
 	if (!ia32_sys_call_table) {
 	    printf("Warning: Failed to find address of ia32_sys_call_table\n");
 	} else {
-	    printf("Found ia32_sys_call_table at %x\n", ia32_sys_call_table);
+	    printf("Found ia32_sys_call_table at %lx\n", (unsigned long)ia32_sys_call_table);
 	}
 #else
-	printf("Found ia32_sys_call_table at %x\n", ia32_sys_call_table);
+	printf("Found ia32_sys_call_table at %lx\n", (unsigned long)ia32_sys_call_table);
 #endif /* IA32_SYS_CALL_TABLE */
 #endif
 
@@ -536,8 +585,6 @@ void
 cleanup_module(void)
 #endif
 {
-    struct task_struct *t;
-
     osi_sysctl_clean();
     if (sys_call_table) {
 #if defined(AFS_IA64_LINUX20_ENV)
